fisx: fisx::Shell Class Reference

fisx

Public Member Functions | List of all members
fisx::Shell Class Reference

## Public Member Functions
| Shell (std::string name)
void | setRadiativeTransitions (std::map< std::string, double >)
void | setRadiativeTransitions (std::vector< std::string >, std::vector< double > values)
void | setRadiativeTransitions (const char *strings[], const double *values, int nValues)
void | setNonradiativeTransitions (std::vector< std::string >, std::vector< double > values)
void | setNonradiativeTransitions (std::map< std::string, double > values)
void | setNonradiativeTransitions (const char *strings[], const double *values, int nValues)
const std::map< std::string, double > & | getAugerRatios () const
const std::map< std::string, std::map< std::string, double > > & | getCosterKronigRatios () const
const std::map< std::string, double > & | getFluorescenceRatios () const
const std::map< std::string, double > & | getRadiativeTransitions () const
const std::map< std::string, double > & | getNonradiativeTransitions () const
std::map< std::string, double > | getDirectVacancyTransferRatios (const std::string &destination) const
void | setShellConstants (std::map< std::string, double >)
const std::map< std::string, double > & | getShellConstants () const
bool | StringToInteger (const std::string &str, int &number)
double | getFluorescenceYield () const

## Constructor & Destructor Documentation

## § Shell()

fisx::Shell::Shell | ( | std::string | name | ) |

Shell constructor. Only shells K, L1, L2, L3, M1, M2, M3, M4 or M5 accepted

## Member Function Documentation

## § getAugerRatios()

const std::map< std::string, double > & fisx::Shell::getAugerRatios | ( |  | ) | const

Get Auger transition ratios

## § getCosterKronigRatios()

const std::map< std::string, std::map< std::string, double > > & fisx::Shell::getCosterKronigRatios | ( |  | ) | const

Get Coster-Kronig transition ratios

## § getDirectVacancyTransferRatios()

std::map< std::string, double > fisx::Shell::getDirectVacancyTransferRatios | ( | const std::string & | destination | ) | const

Return the probabilities of direct transfer of a vacancy to a higher shell following an X-ray emission, an Auger transition and Coster-Kronig transitions (if any). Since the different types of transitions are normalized, it multiplies by the fluorescence, Auger or Coster-Kronig yields to get the probabilities.

## § getFluorescenceRatios()

const std::map< std::string, double > & fisx::Shell::getFluorescenceRatios | ( |  | ) | const

Get X-ray fluorescence transition ratios

## § setNonradiativeTransitions()

void fisx::Shell::setNonradiativeTransitions | ( | std::vector< std::string > | labels,
|  | std::vector< double > | values
| ) |  |

Set the non-radiative transitions probabilities originating on this shell The transition labels have to start by the name used to instantiate the class, followed by a a hyphen, the origin shell of the filling electron and the shell from which the additional electron is ejected. (Examples: L1-L2M2, ...) The class normalizes the provided intensities separating Auger and Coster-Kronig ratios.

## § setRadiativeTransitions() [1/3]

void fisx::Shell::setRadiativeTransitions | ( | std::map< std::string, double > | inputMap | ) |

Set the radiative transitions probabilities. The transition labels have to start by the name used to instantiate the class. Valid examples: KL3, L3M5, ... The class normalizes the provided intensities.

## § setRadiativeTransitions() [2/3]

void fisx::Shell::setRadiativeTransitions | ( | std::vector< std::string > | labels,
|  | std::vector< double > | values
| ) |  |

Convenience method

## § setRadiativeTransitions() [3/3]

void fisx::Shell::setRadiativeTransitions | ( | const char * | strings[],
|  | const double * | values,
|  | int | nValues
| ) |  |

Convenience method

## § setShellConstants()

void fisx::Shell::setShellConstants | ( | std::map< std::string, double > | shellConstants | ) |

Set the shell constants. omega denotes the fluorescence yield of the shell fij represents the Coster-Kronig yield The Auger yield is calculated as 1 - omega - sum(fij) WARNING: The original constants are not cleared Only those constants supplied will be overwritten!!!

The documentation for this class was generated from the following files:

- fisx_shell.h
- fisx_shell.cpp